summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author MetalliC <0vetal0@gmail.com>2017-09-15 19:34:50 +0300
committer MetalliC <0vetal0@gmail.com>2017-09-15 19:34:50 +0300
commitee7472ae05b4ea261dbfb7258db933503ee1ab23 (patch)
treea038fa7a28b24a8b3c7da5463d6fab93edc0ce91
parentf45827589d2d56c3195cd66328569c54188dea98 (diff)
notes and its corrections (nw)
-rw-r--r--src/mame/drivers/dccons.cpp43
-rw-r--r--src/mame/drivers/naomi.cpp6
2 files changed, 25 insertions, 24 deletions
diff --git a/src/mame/drivers/dccons.cpp b/src/mame/drivers/dccons.cpp
index 4f21c9f4495..e1fa2eaaf8a 100644
--- a/src/mame/drivers/dccons.cpp
+++ b/src/mame/drivers/dccons.cpp
@@ -660,15 +660,15 @@ struct factory_sector
{
struct factory_record {
// everything 'char' below is decimal numbers in ASCII, unless noted else
- char machine_code1; // '0' - Dreamcast, 0xFF - dev.box
- char machine_code2; // '0' - Dreamcast, 0xFF - dev.box
- char country_code; // 0 - Japan, 1 - America, 2 - Europe
- char language; // 0 - Japanese, 1 - English, etc
- char broadcast_format; // 0 - NTSC, 1 - PAL, 2 - PAL-M, 3 - PAL-N
- char machine_name[32]; // ASCII text 'Dreamcast', trail is 0x20 filled
- char tool_number[4]; // software tool #
- char tool_version[2]; // software tool version
- char tool_type[2]; // software tool type: 0 - MP(mass production?), 1 - Repair
+ char machine_code1; // '0' - Dreamcast, 0xFF - dev.box
+ char machine_code2; // '0' - Dreamcast, 0xFF - dev.box
+ char country_code; // 0 - Japan, 1 - America, 2 - Europe
+ char language; // 0 - Japanese, 1 - English, etc
+ char broadcast_format; // 0 - NTSC, 1 - PAL, 2 - PAL-M, 3 - PAL-N
+ char machine_name[32]; // ASCII text 'Dreamcast', trail is 0x20 filled
+ char tool_number[4]; // software tool #
+ char tool_version[2]; // software tool version
+ char tool_type[2]; // software tool type: 0 - for MP(mass production?), 1 - for Repair, 2 - for PP
char year[4];
char month[2];
char day[2];
@@ -677,17 +677,18 @@ struct factory_sector
char serial_number[8];
char factory_code[4];
char total_number[16];
- uint8_t sum; // byte sum of above
- uint8_t machine_id[8]; // 64bit UID
- uint8_t machine_type; // FF - Dreamcast
- uint8_t hardware_version; // FF - VA0, FE - VA1, FD - VA2, NOTE: present in 1st factory record only, in 2nd always FF
- } factory_records[2]; // 2 copies
- uint8_t unused_0[0x36]; // FF filled
- uint8_t unk_version; // not clear if hardware or bios version, A0 - VA0, 9F - VA1, 9E - VA2
- uint8_t unused_1[9]; // FF filled
- char staff_roll[0xca0]; // list of creators
- uint8_t unused_2[0x420]; // FF filled
- uint8_t random[0xdc0]; // output of RNG {static u32 seed; seed=(seed*0x83d+0x2439)&0x7fff; return (u16)(seed+0xc000);}, where initial seed value is serial_number[7] & 0xf
+ uint8_t sum; // byte sum of above
+ uint8_t machine_id[8]; // 64bit UID
+ uint8_t machine_type; // FF - Dreamcast
+ uint8_t machine_version;// FF - VA0, FE - VA1, FD - VA2, NOTE: present in 1st factory record only, in 2nd always FF
+ uint8_t unused[0x40] // FF filled
+ } factory_records[2]; // 2 copies
+ uint8_t unused_0[0x36]; // FF filled
+ uint8_t unk_version; // not clear if hardware or bios version, A0 - VA0, 9F - VA1, 9E - VA2
+ uint8_t unused_1[9]; // FF filled
+ char staff_roll[0xca0]; // list of creators
+ uint8_t unused_2[0x420]; // FF filled
+ uint8_t random[0xdc0]; // output of RNG {static u32 seed; seed=(seed*0x83d+0x2439)&0x7fff; return (u16)(seed+0xc000);}, where initial seed value is serial_number[7] & 0xf
};
*/
@@ -712,7 +713,7 @@ ROM_START( dcjp )
ROM_LOAD_BIOS(4, "mpr-21068.ic501", 0x000000, 0x200000, CRC(5454841f) SHA1(1ea132c0fbbf07ef76789eadc07908045c089bd6) )
ROM_REGION(0x020000, "dcflash", 0)
- ROM_LOAD( "dcjp_ntsc.bin", 0x000000, 0x020000, CRC(306023ab) SHA1(5fb66adb6d1b54a552fe9c2bb736e4c6960e447d) ) // from VA0 with 1.004 BIOS
+ ROM_LOAD( "dcjp_ntsc.bin", 0x000000, 0x020000, CRC(306023ab) SHA1(5fb66adb6d1b54a552fe9c2bb736e4c6960e447d) ) // from refurbished VA0 with 1.004 BIOS
ROM_END
// unauthorised portable modification
diff --git a/src/mame/drivers/naomi.cpp b/src/mame/drivers/naomi.cpp
index 1957e873d10..5469f8a757f 100644
--- a/src/mame/drivers/naomi.cpp
+++ b/src/mame/drivers/naomi.cpp
@@ -5650,7 +5650,7 @@ ROM_START( shootplm )
NAOMI_DEFAULT_EEPROM
ROM_REGION( 0x3000000, "rom_board", ROMREGION_ERASEFF)
- ROM_LOAD( "epr-24148.ic11", 0x000000, 0x400000, CRC(d575f311) SHA1(7f45d897412fd75eda740a82320fce08331fa310) )
+ ROM_LOAD( "epr-24148.ic11", 0x000000, 0x400000, CRC(d575f311) SHA1(7f45d897412fd75eda740a82320fce08331fa310) ) // Build: 23 Jan 2004
ROM_LOAD32_WORD( "opr-24174.ic17s", 0x1000000, 0x800000, CRC(ccd6aec5) SHA1(a8105ce6986601d8673ffea41353fe399cf8557d) )
ROM_LOAD32_WORD( "opr-24175.ic18", 0x1000002, 0x800000, CRC(e66e6345) SHA1(28a372168419c9352cb7fc5285bbd37bd37f3b71) )
ROM_LOAD32_WORD( "opr-24176.ic19s", 0x2000000, 0x800000, CRC(1277bca8) SHA1(e1bd9d1a6f4170a9c29658f95e9e96caf4b0cb84) )
@@ -10162,8 +10162,8 @@ ROM_END
/* 0128 */ GAME( 2003, shootpl, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) (Rev A)", GAME_FLAGS )
/* 0130 */ GAME( 2002, hopper, naomi, naomi, naomi, naomi_state, naomi, ROT0, "Sega", "SWP Hopper Board", GAME_FLAGS )
// 0132 Mushiking 2K3 2ND (Japan)
/* 0136 */ GAME( 2004, shootplm, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) Version B", GAME_FLAGS )
/* 0136 */ GAME( 2004, shootplmp, shootplm, naomim2, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) Version B -P", GAME_FLAGS )
/* 0140 */ GAME( 2004, kick4csh, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Kick '4' Cash (Export)", GAME_FLAGS )
/* 0150 */ GAME( 2003, mtkob2, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Mushiking The King Of Beetle (2K3 2ND, World)", GAME_FLAGS ) // not for Japan
/* 0152 */ GAME( 2004, mushi2k4, naomi, naomim2, naomi, naomi_state, naomi, ROT0, "Sega", "Mushiking The King Of Beetles 2004 Second (Japan)", GAME_FLAGS )
@@ -10162,8 +10162,8 @@ ROM_END
/* 0130 */ GAME( 2002, hopper, naomi, naomi, naomi, naomi_state, naomi, ROT0, "Sega", "SWP Hopper Board", GAME_FLAGS )
// 0132 Mushiking 2K3 2ND (Japan)
-/* 0136 */ GAME( 2004, shootplm, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) Version B", GAME_FLAGS )
-/* 0136 */ GAME( 2004, shootplmp, shootplm, naomim2, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) Version B -P", GAME_FLAGS )
+/* 0136 */ GAME( 2004, shootplm, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) Version B", GAME_FLAGS ) // Build: 23 Jan 2004
+/* 0136 */ GAME( 2004, shootplmp, shootplm, naomim2, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) Version B -P", GAME_FLAGS ) // Build: 15 Dec 2003
/* 0140 */ GAME( 2004, kick4csh, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Kick '4' Cash (Export)", GAME_FLAGS )
/* 0150 */ GAME( 2003, mtkob2, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Mushiking The King Of Beetle (2K3 2ND, World)", GAME_FLAGS ) // not for Japan